@@ -1,6 +1,8 @@
 """
 implementation of the Box_dictionary class and its helper function
+A Box_dictionary object contains the sketches present in each image. Its methods collect and modify the sketches
 """
+
 from typing import Union,List,Dict,Tuple
 from cryoloBM import constants,helper,MySketch,helper_filament
 from cryolo import utils    # for type hinting purpose
@@ -98,6 +100,10 @@ class Box_dictionary:
 
 
     def _init_dict_folder_case(self, onlyfiles:List[str])-> None:
+        """
+        Init all the dicts
+        :param onlyfiles: list of filename, each filename identifies an image
+        """
         for f in onlyfiles:
             self.particle_dictionary.update({path.splitext(path.basename(f))[0]: list() if self.type_case == constants.Type_case.SPA.value else dict()})
             self.particle3D_dictionary.update({path.splitext(path.basename(f))[0]: list() if self.type_case == constants.Type_case.SPA.value else dict()})
@@ -688,7 +694,7 @@ class Box_dictionary:
 
     def clean(self)->None:
         """
-        clean the dict
+        clean the dicts
         """
         self.particle_dictionary = dict()
         self.particle3D_dictionary = dict()
