@@ -572,6 +572,17 @@ def use_estimated_size_changed(controller:boxmanager_controller)->None:
         draw_all_patches(controller=controller)
         controller.view.fig.canvas.blit(controller.view.ax.bbox)
 
+def _change_all_boxsizes_folder(controller:boxmanager_controller, new_boxsize: int):
+    for f in controller.model.params:
+        controller.model.params[f].box_size = new_boxsize
+        num_frames = controller.model.tot_frames[f]
+        for n in range(num_frames):
+            boxes = controller.model.box_dictionary.get_sketches(f=f, n=n, is_3D=controller.model.has_3d,
+                                                                 is_tracing=False)
+            for box in boxes:
+                box.resize(new_size=new_boxsize)
+
+
 def box_size_changed(controller:boxmanager_controller, box_size_from_file:int = None)->None:
     """
     It changes the value of the "box size" filling the 'box size' line in the visualization tab.
@@ -609,11 +620,9 @@ def box_size_changed(controller:boxmanager_controller, box_size_from_file:int =
         controller.view.err_message( msg="Invalid value. It has to be a positive number")
         return
 
-    current_filename = controller.get_current_filename(with_extension=False)
-
     # update the params var. Since this is a high consuming time operation we perform it only in the current tomo
     if controller.model.type_case == constants.Type_case.TOMO_FOLDER.value:
-        controller.model.params[current_filename].box_size = controller.model.boxsize
+        _change_all_boxsizes_folder(controller, controller.model.boxsize)
 
     if controller.model.rectangles:
         #remove the old patches, they are already saved in controller.model.rectangles
@@ -642,6 +651,7 @@ def box_size_changed(controller:boxmanager_controller, box_size_from_file:int =
         controller.view.fig.canvas.blit(controller.view.ax.bbox)
 
 
+
 def box_distance_filament_changed(controller:boxmanager_controller, box_distance:int = 1)->None:
     # After clicking 'h' the boxes disappear, before acting i have to untoggle
     if controller.model.toggle:
