@@ -257,7 +257,7 @@ def import_SPA(controller:boxmanager_controller, box_dir:str, keep:bool)->bool:
     pd.show()
 
     star_dialog_was_shown = False
-    is_star_startend = False
+    is_star_filament = False
 
     controller.view.is_updating_params = True
     valid_import = False
@@ -269,25 +269,21 @@ def import_SPA(controller:boxmanager_controller, box_dir:str, keep:bool)->bool:
 
         is_helicon = CoordsIO.is_eman1_helicon(path=pathfile)
         is_eman1_startend = CoordsIO.is_eman1_filament_start_end(path=pathfile) if not is_helicon else False
-        if not is_helicon and not is_eman1_startend:
-            if not star_dialog_was_shown and f.endswith(".star"):
-                is_star_startend =  controller.view.qtmessage( msg="Are the star files containing filament coordinates (start/end)?",
-                                has_cancel=False) == controller.view.clicked_yes()
-                star_dialog_was_shown = True
+        is_star_filament = CoordsIO.is_star_filament_file(path=pathfile)
 
         # if the file is empty i want just to check the related checkbox
         if os_stat(path.join(box_dir, f)).st_size == 0:
-            dict_entry_name = _update_entries_empty_file(f=f, updated_entries=updated_entries, is_star_startend=is_star_startend, is_helicon=is_helicon, is_eman1_startend=is_eman1_startend)
+            dict_entry_name = _update_entries_empty_file(f=f, updated_entries=updated_entries, is_star_startend=is_star_filament, is_helicon=is_helicon, is_eman1_startend=is_eman1_startend)
             continue
 
-        if any([is_helicon, is_eman1_startend, is_star_startend]):
+        if any([is_helicon, is_eman1_startend, is_star_filament]):
             filaments = list()
             dict_entry_name = f[:-4]
             if is_helicon:
                 filaments = CoordsIO.read_eman1_helicon(pathfile)
             elif is_eman1_startend:
                 filaments = CoordsIO.read_eman1_filament_start_end(pathfile)
-            elif is_star_startend:
+            elif is_star_filament:
                 print(f"Read filaments {pathfile}")
                 filaments = CoordsIO.read_star_filament_file(
                     path=pathfile, box_width=100
@@ -387,8 +383,9 @@ def _setting_boxdictionary_vars(controller:boxmanager_controller)->None:
             controller.model.has_3d = False
             controller.model.box_dictionary.set_untraced_param()
 
-
+next_color = "black"
 def import_single_tomo(controller:boxmanager_controller, path_3d_file:str, index_file:Union[int,None], keep:bool)->bool:
+    global next_color
     """
     Import the boxes of a single tomo from file.
     In case it cannot (we try to import particle when we are displaying filament or viceversa) return False.
@@ -454,7 +451,11 @@ def import_single_tomo(controller:boxmanager_controller, path_3d_file:str, index
         for box in boxes:
             sketch = box_to_sketch(controller=controller, box=box, color=rand_color)
             box_imported += 1
-            controller.model.box_dictionary.add_sketch(sketch=sketch, f=filename, n=int(box.z))
+            try:
+                controller.model.box_dictionary.add_sketch(sketch=sketch, f=filename, n=int(box.z))
+            except:
+                print("error import box. continue")
+                continue
 
     updated_entries = [str(int(z)) for z in CoordsIO.read_cbox_include_list(path=path_3d_file + ".cbox")]
     item =  controller.view.tree.invisibleRootItem().child(0).child(index_file) if index_file is not None else controller.view.tree.invisibleRootItem()
