@@ -3,6 +3,7 @@ In this file i declare all the logic related to the dropdown menu calls in order
 boxmanager_controller.py code letting into it only the calls to the function (of course functions like 'reset_config'
 that have only fews line of code are, for now, still into the file)
 """
+
 from cryoloBM import constants, helper, helper_GUI, helper_image
 from os import path
 from mrcfile import mmap as mrcfile_mmap        #it is not in the setup.py because it is already installed by cryolo
@@ -10,7 +11,7 @@ from numpy import min as np_min, max as np_max, isnan as np_isnan, sum as np_sum
 import matplotlib.pyplot as plt
 
 from cryoloBM import boxmanager_controller,MySketch # for type hinting purpose
-from typing import Union,List,Dict,Tuple
+from typing import List,Tuple
 
 def close_boxmanager(controller:boxmanager_controller)->None:
     """
