@@ -144,7 +144,7 @@ def write_all_type_optimization(controller:boxmanager_controller, box_dir:str, s
         pd.show()
 
         if file_type == "CBOX_UNTRACED":
-            box_dictionary_to_save, ignored_slice, empty_slice = prepare_output(controller= controller, slices=selected_slices,is_tracing=True)
+            box_dictionary_to_save, ignored_slice, empty_slice = prepare_output(controller= controller, slices=selected_slices,is_tracing=False)
 
             # at 19.02.21 the picking filament is not enabled
             # after the tracing we save into 'CBOX_UNTRACED' the input value gave to 'grouping3d.do_tracing' called int 'helper_tab_tracing.trace_values'
@@ -429,7 +429,9 @@ def write_coordinates_micrograph(controller:boxmanager_controller, pd:helper_GUI
             num_writtin_part = num_writtin_part + len(rectangles)
             boxes += rectangles
         else:
-            if is_cbox:
+            import numbers
+
+            if isinstance(rectangles[0].get_confidence(), numbers.Number):
                 rectangles = [
                     box for box in rectangles if
                     helper.check_if_should_be_visible(box=box, current_conf_thresh=controller.model.current_conf_thresh,
